"""Sub-level module 'data' for glacier-flow-model package."""
from .access import PkgDataAccess

__all__ = ["PkgDataAccess"]
